@@ -603,7 +603,7 @@ class Action(MethodsInterface):
         self.group_name = ""
         self.clVars = dv
         if dv.Get('cl_env_debug_set') == 'off' or \
-                dv.Get('cl_ebuild_phase'):
+                dv.Get('cl_ebuild_phase') or os.getuid():
             logger = StubLogger()
         else:
             logger = log("core-action.log",
